These files are soft links to 
1kgPhase1chr1.vcf.gz -> tests/data/variants/1kgPhase1/chr1.vcf.gz
1kgPhase1chr1.vcf.gz.tbi -> tests/data/variants/1kgPhase1/chr1.vcf.gz.tbi
1kgPhase3chr2.vcf.gz -> tests/data/variants/1kgPhase3/chr2.vcf.gz
1kgPhase3chr2.vcf.gz.tbi -> tests/data/variants/1kgPhase3/chr2.vcf.gz.tbi

